#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/install.sh - xinet installation
#
# Creation   : 2008-08-16 dv
# Last update: $Id$
#
# Copyright (c) 2008 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# setup system specific values  
if [ -z "${EISFAIR_SYSTEM}" ]
then
    # get eisfair system-type
    . /var/install/include/check-eisfair-version
fi

case "${EISFAIR_SYSTEM}" in
    eisfair-1)
        runuser="ftp"
        runuid="28"
        ;;
    *)
        runuser="ftp"
        runuid="128"
        ;;
esac

#-----------------------------------------------------------------------------
# start/stop script
#-----------------------------------------------------------------------------
stopplevels="/etc/rc0.d /etc/rc1.d /etc/rc6.d"
startlevels="/etc/rc2.d"

case "${EISFAIR_SYSTEM}" in
    eisfair-1)
        cd /etc/rc2.d
        rm -f K??xinet
        rm -f S??xinet
        ln -sf ../init.d/xinet K50xinet
        cd - >/dev/null 2>&1
        ;;
    *)
        for level in $stopplevels  
        do
            if [ -d "$level" ]
            then
                cd "$level"
                rm -f K??xinet
                ln -sf ../init.d/xinet K50xinet
                cd - >/dev/null 2>&1
            fi
        done

        for level in $startlevels
        do
            if [ -d "$level" ]
            then
                cd "$level"
                rm -f K??xinet
                cd - >/dev/null 2>&1
            fi
        done
        ;;
esac


#-----------------------------------------------------------------------------
# add user ftp for anonymous ftp logins
#-----------------------------------------------------------------------------
grep '^ftp:' /etc/passwd >/dev/null
if [ $? != 0 ]
then
    echo "Adding user ftp..."
    /var/install/bin/add-user $runuser '*' $runuid '' "anonymous_ftp" /home/ftp /bin/false 2>&1 >/dev/null
    echo
fi

# ----------------------------------------------------------------------------
# Create directory
# ----------------------------------------------------------------------------
mkdir -p          /tftpboot 2>&1 >/dev/null
chmod 0755        /tftpboot
chown root.root   /tftpboot
mkdir -p          /home/ftp 2>&1 >/dev/null
chown ftp.users   /home/ftp

#-------------------------------------------------------------------------------
# Add menu
#-------------------------------------------------------------------------------
/var/install/bin/add-menu   setup.services.menu   \
                            setup.services.xinet.menu    \
                            "Internet/Intranet Services"

# ----------------------------------------------------------------------------
# Create default config
# ----------------------------------------------------------------------------
/var/install/config.d/xinet-update.sh
/var/install/config.d/xinet.sh

# ----------------------------------------------------------------------------
# start server if configured so
# ----------------------------------------------------------------------------
if [ -f /etc/rc2.d/S50xinet ]
then
    /etc/init.d/xinet start
fi

exit 0

# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
