#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/xinet-update.sh - paramater update script
#
# Creation   : 2008-08-16 dv
# Last update: $Id$
#
# Copyright (c) 2008 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/xinet-update-trace$$.log
#set -x

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=xinet

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_XINET='no'
XINET_ENABLE_TIME='no'
XINET_ENABLE_TELNET='no'
XINET_ENABLE_FTP='no'
XINET_FTP_LOG='yes'
XINET_FTP_MAX_TIMEOUT='7200'             # default
XINET_FTP_IDLE_TIMEOUT='900'             # default
XINET_FTP_GUEST_LOGIN='no'
XINET_ENABLE_TFTP='no'
XINET_TFTP_ADD_ARGS=''

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
#-----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/xinet ]
    then
        . /etc/config.d/xinet
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf xinet "2008-08-16" "dv"
    # ------------------------------------------------------------------------

    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_XINET"         "Enable start of xinetd"
    printvar "XINET_ENABLE_TIME"   "Enable RFC868 time service on port 37"
    printvar "XINET_ENABLE_TELNET" "Enable telnet access (obsolete)"
    printvar "XINET_ENABLE_FTP"    "Enable ftp access (obsolete)"
    printvar "XINET_ENABLE_TFTP"   "Enable tftp access"
    printvar "XINET_TFTP_ADD_ARGS" "Additional arguments for tftpd"

    # ------------------------------------------------------------------------
    printgroup "FTP options"
    # ------------------------------------------------------------------------
    printvar "XINET_FTP_LOG"       "Write acitivies to syslog"
    printvar "XINET_FTP_MAX_TIMEOUT" "Maximum session timeout"
    printvar "XINET_FTP_IDLE_TIMEOUT" "Maximum idle time"
    printvar "XINET_FTP_GUEST_LOGIN" "Enable anonymous logins"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{
printgpl -check xinet '2008-08-16' 'root' >/etc/check.d/xinet
cat >>/etc/check.d/xinet <<EOFG
# Variable           OPT_VARIABLE      VARIABLE_N          VALUE
START_XINET            -                 -                   YESNO
XINET_ENABLE_TIME      START_XINET       -                   YESNO
XINET_ENABLE_TELNET    START_XINET       -                   YESNO
XINET_ENABLE_FTP       START_XINET       -                   YESNO
XINET_ENABLE_TFTP      START_XINET       -                   YESNO
XINET_TFTP_ADD_ARGS    XINET_ENABLE_TFTP -                   NONE
XINET_FTP_LOG          XINET_ENABLE_FTP  -                   YESNO
XINET_FTP_MAX_TIMEOUT  XINET_ENABLE_FTP  -                   NUMERIC
XINET_FTP_IDLE_TIMEOUT XINET_ENABLE_FTP  -                   NUMERIC
XINET_FTP_GUEST_LOGIN  XINET_ENABLE_FTP  -                   YESNO
EOFG

# Set rights for check.d file
chmod 0600 /etc/check.d/xinet
chown root /etc/check.d/xinet

# no exp-file required right now
printgpl -check_exp xinet '2008-08-16' 'root' >/etc/check.d/xinet.exp
cat >>/etc/check.d/xinet.exp <<EOFG
EOFG

# Set rights for check.exp file
chmod 0600 /etc/check.d/xinet.exp
chown root /etc/check.d/xinet.exp

# no ext-file required right now
#printgpl -check_ext xinet '2008-08-16' 'root' >/etc/check.d/xinet.ext
#cat >>/etc/check.d/xinet.ext <<EOFG
#EOFG

# Set rights for check.ext file
#chmod 0600 /etc/check.d/xinet.ext
#chown root /etc/check.d/xinet.ext
}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
if [ -f /etc/config.d/xinet ]
then
    mecho -info -n "Updating configuration. "
else
    mecho -info -n "creating configuration. "
fi

makeConfigFile /etc/default.d/xinet

# Update from old version
mecho -info -n "."
renameOldVariables

# Write new config file
mecho -info -n "."
makeConfigFile /etc/config.d/xinet

# Write check.d file
mecho -info -n "."
makeCheckFile

mecho -info "Finished."

exit 0

# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
