#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/xinet - XINET configuration
#
# Creation   : 2008-08-16 dv
# Last update: $Id$
#
# Copyright (c) 2008 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# Config Dateien
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# include config
. /etc/config.d/xinet

# set package name
packageName=xinet

#-------------------------------------------------------------------------------
# create xinetd time service configuration
#-------------------------------------------------------------------------------
create_xinetd_time ()
{
    CONF='/etc/xinetd.d/time'
    TMP="/tmp/xinetd.$$"

    if [ "$XINET_ENABLE_TIME" == "yes" ] 
    then
        disabled='no'
        message='xinetd: time service enabled'
        col='-info'
    else
        disabled='yes'
        message='xinetd: time service disabled'
        col=''
    fi
 	
    sed -e "s|.*disable *=.*|  disable = $disabled|" $CONF > $TMP
    mecho $col $message

    cp $TMP $CONF
    rm $TMP
}

#-------------------------------------------------------------------------------
# create xinetd telnet configuration
#-------------------------------------------------------------------------------
create_xinetd_telnet ()
{
    CONF='/etc/xinetd.d/telnet'
    TMP="/tmp/xinetd.$$"
 	
    if [ "$XINET_ENABLE_TELNET" == "yes" ]
    then
        disabled='no'
        message='xinetd: telnet enabled'
        col='-info'
    else
        disabled='yes'
        message='xinetd: telnet disabled'
        col=''
    fi
 	
    sed -e "s|.*disable *=.*|  disable = $disabled|" $CONF > $TMP
    mecho $col $message
	
    cp $TMP $CONF
    rm $TMP
}

#-------------------------------------------------------------------------------
# create xinetd ftp configuration
#-------------------------------------------------------------------------------
create_xinetd_ftp ()
{
    CONF='/etc/xinetd.d/ftp'
    TMP="/tmp/xinetd.$$"
 	
    if [ "$XINET_ENABLE_FTP" == "yes" ]
    then
        disabled='no'
        message='xinetd: ftp enabled'
        col='-info'
    else
        disabled='yes'
        message='xinetd: ftp disabled'
        col=''
    fi
 	
    sed -e "s|.*disable *=.*|  disable = $disabled|" $CONF > $TMP
    mecho $col $message
    cp $TMP $CONF

    args="-a -T ${XINET_FTP_MAX_TIMEOUT} -t ${XINET_FTP_IDLE_TIMEOUT}"
    if [ "${XINET_FTP_LOG}" == "yes" ]
    then
        args="-l $args"
    fi

    sed -e "s|.*server_args *=.*|  server_args = $args|" $CONF > $TMP
    cp $TMP $CONF
	
    rm $TMP
}

#-------------------------------------------------------------------------------
# create xinetd tftp configuration
#-------------------------------------------------------------------------------
create_xinetd_tftp ()
{
    CONF='/etc/xinetd.d/tftp'
    TMP="/tmp/tftp.$$"

    if [ "$XINET_ENABLE_TFTP" == "yes" ]
    then
        disabled='no'
        message='xinetd: tftpd enabled'
        col='-info'
    else
        disabled='yes'
        message='xinetd: tftpd disabled'
        col=''
    fi
 	
    sed -e "s|.*disable *=.*|  disable = $disabled|" $CONF > $TMP
    mecho $col $message
    cp $TMP $CONF
 	
    sed -e "s|.*server_args *=.*|  server_args = -s $XINET_TFTP_ADD_ARGS /tftpboot|" $CONF > $TMP
    cp $TMP $CONF
	
    rm $TMP
}

# ----------------------------------------------------------------------------
# create/remove start link
# ----------------------------------------------------------------------------
create_xinetd_links()
{
    if [ "$START_XINET" = "yes" ]
    then
        ln -sf /etc/init.d/xinet /etc/rc2.d/S50xinet
    else
        if [ -f /etc/rc2.d/S50xinet ]
        then
            rm -f /etc/rc2.d/S50xinet
        fi
    fi
}

# ----------------------------------------------------------------------------
# write users to be rejected
# ----------------------------------------------------------------------------
write_ftp_users()
{
    if [ "${XINET_ENABLE_FTP}" == "yes" ]
    then
        echo "root" > /etc/ftpusers
        if [ "${XINET_FTP_GUEST_LOGIN}" == "no" ]
        then
            echo "anonymous" > /etc/ftpusers
            echo "ftp" > /etc/ftpusers
        fi
    fi
}

# ----------------------------------------------------------------------------
# write ftp access file
# ----------------------------------------------------------------------------
write_ftp_access()
{
    if [ "${XINET_ENABLE_FTP}" == "yes" ]
    then
        cat >>/etc/ftpaccess <<EOFG
#-------------------------------------------
# FTP access file for wu-ftpd
# this file has been generated automatically 
# by xinet
#-------------------------------------------
class   users   real,guest  *
class   guests  anonymous  *

noretrieve /etc /home/*/.* /proc
noretrieve core

anonymous-root /home/ftp

upload /home/ftp / yes ftp users 0440
EOFG
        # Set rights for check.d file
        chmod 0600 /etc/ftpaccess
        chown root /etc/ftpaccess
    fi
}


# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
create_xinetd_telnet
create_xinetd_ftp
create_xinetd_tftp
create_xinetd_time
create_xinetd_links
write_ftp_users
write_ftp_access

# create/remove start link
if [ "$START_XINET" = "yes" ]
then
    ln -sf /etc/init.d/xinet /etc/rc2.d/S50xinet
else
    if [ -f /etc/rc2.d/S50xinet ]
    then
        rm -f /etc/rc2.d/S50xinet
    fi
fi


exit 0

# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------

